kombu.transport.beanstalk — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

# kombu.transport.beanstalk

Beanstalk transport.

copyright: | 2010 - 2011 by David Ziegler.
license: | BSD, see LICENSE for more details.

- Transport
- Channel

## Transport

class `kombu.transport.beanstalk.` `Transport`(client, **kwargs)
  class `Channel`(connection, **kwargs)
    `client`
    `close`()

## Channel

class `kombu.transport.beanstalk.` `Channel`(connection, **kwargs)
  `client`
  `close`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »